Crate lustre_executor

Crate lustre_executor 

lustre-executor

A blazingly fast, minimal async executor built on Mio for low-level I/O. Features pluggable ID generation, modular design, and support for custom futures.

Example

use lustre_executor::prelude::*;

let mut executor = Executor::new().unwrap();
executor.spawn(Task::new(async {
    // Your async code here
}));
executor.run();

Re-exports

pub use core::*;
pub use io::*;
pub use prelude::*;

Modules

core
io
I/O futures and utilities.
prelude