Crate lustre_executor

Crate lustre_executor 

lustre-executor

A blazingly fast, minimal async executor built on Mio for low-level I/O. Features pluggable ID generation, modular design, and support for custom futures.

Example

use lustre_executor::prelude::*;

let mut executor = Executor::new().unwrap();
executor.spawn(Task::new(async {
    // Your async code here
}));
executor.run();

Re-exports

pub use executor::*;
pub use id::*;
pub use io::*;
pub use reactor::*;
pub use task::*;

Modules

executor
id
io
prelude
reactor
task